@@ -145,6 +145,11 @@ class LoopN(object):
         else:
             self.__dict__[name] = val_new
 
+    def is_attribute(self, name: str):
+        """Give True if all attributes are defined."""
+        flag = all([item.is_attribute(name) for item in self.items])
+        return flag
+
     def numpy_to_items(self) -> NoReturn:
         """
         Transform all internal numpy arrays to elements of items.
@@ -175,6 +180,9 @@ class LoopN(object):
         for name in del_name:
             del self.__dict__[name]
 
+    def form_object(self):
+        pass
+
     @classmethod
     def from_cif(cls, string: str):
         """
@@ -324,8 +332,8 @@ class LoopN(object):
         prefix = item_0.PREFIX
         ls_out_2 = []
         for name, name_cif in zip(item_0.ATTR_NAMES, item_0.ATTR_CIF):
-            value = getattr(item_0, name)
-            if value is not None:
+            flag_value = item_0.is_attribute(name)
+            if flag_value:
                 ls_out.append(f"_{prefix:}{separator:}{name_cif:}")
                 list_value = [getattr(item, f"{name}_as_string")
                               for item in self.items]
