@@ -104,8 +104,9 @@ class Cell(ItemN):
 
     def apply_constraints(self):
         """Apply constraints."""
-        if ((self.type_cell is None) | (self.it_coordinate_system_code is
-                                        None)):
+        flag_1 = not(self.is_attribute("type_cell"))
+        flag_2 = not(self.is_attribute("it_coordinate_system_code"))
+        if (flag_1 | flag_2):
             return
         cell_p = (self.length_a, self.length_b, self.length_c,
                   self.angle_alpha, self.angle_beta, self.angle_gamma)
